@@ -236,20 +236,34 @@ char long_name[MAXPATHLEN<<2] = { '\0' };
 int
 rt_loc_line(void)
 {
-	int     i;
+#define strneq(a,b,n) strncmp(a,b,n)==0
 
-	if ((i = strncmp(cur_line, dds_locline1, 45)) == 0) {
+	if ( strneq(cur_line, dds_locline1, 45) ) {
 		tar_fb = atoi(cur_line + 45);
-	} else if ((i = strncmp(cur_line, "first block number is", 21)) == 0) {
+	} else
+	if ( strneq(cur_line, "first block number is", 21) ) {
 		tar_fb = atoi(cur_line + 21);
-	} else if ((i = strncmp(cur_line, dds_locline2, 31)) == 0) {
+	} else
+	if ( strneq(cur_line, dds_locline2, 31) ) {
 		tar_n = atoi(cur_line + 31);
 		tar_bs = tar_n >> 9;
-	} else if ((i = strncmp(cur_line, "block size is", 13)) == 0) {
+	} else
+	if ( strneq(cur_line, "block size is", 13) ) {
 		tar_bs = atoi(cur_line + 13);
 		tar_n = tar_bs << 9;
 	} else
+	if ( strneq(cur_line, "block length is", 15) ) {
+		tar_n = atoi(cur_line + 15) ;
+		tar_bs = tar_n >> 9 ;
+	} else {
 		return 1;
+	}
+
+	if ( verbose ) fprintf(stderr,
+		"block length is %d = %d * 512 \n", tar_n, tar_bs );
+
+#undef strneq
+
 	if ( buf_n < tar_n ) {
 		cur_block = realloc ( cur_block , buf_n = tar_n );
 		if ( cur_block == NULL ) {
@@ -364,7 +378,7 @@ strprefix(char**s,char*p,char*q){
  * dds2tar
  */
 int
-main(int argc, char const *const *argv)
+main(int argc, char *const *argv)
 {
 
 #ifndef DEVICE
@@ -614,7 +628,11 @@ main(int argc, char const *const *argv)
 				child_proc = creopen(1, 0, a[0], a);
 			}
 			ELSE {
-				pattern_list = argv + n;
+				{
+					char*const*p = argv+n ;
+					while (*p) dds_unquote(*p++) ;
+				}
+				pattern_list = (const char*const*)argv + n;
 				if (verbose)
 					fprintf(stderr,
 						"first pattern is '%s'\n",
