@@ -10,6 +10,10 @@ extern void dds_read_block(void);
 extern void dds_read_next_block(void);
 extern int dds_getpos(int const dev);
 extern int dds_seek(int const dev ,int const blkno);
+extern int dds_get_bs(void);
+extern int dds_read_ahead(void);
+
+extern int dds_has_partitions(int const dev);
 
 #define DDSCM_NULL -1
 #define DDSCM_OFF 0
